@@ -1533,7 +1533,7 @@ parse_animator_property (JsonArray *array,
   JsonObject *object;
   JsonArray *keys;
   GObject *gobject;
-  const gchar *id, *pname;
+  const gchar *id_, *pname;
   GObjectClass *klass;
   GParamSpec *pspec;
   GSList *valid_keys = NULL;
@@ -1563,11 +1563,11 @@ parse_animator_property (JsonArray *array,
       return;
     }
 
-  id = json_object_get_string_member (object, "object");
-  gobject = clutter_script_get_object (clos->script, id);
+  id_ = json_object_get_string_member (object, "object");
+  gobject = clutter_script_get_object (clos->script, id_);
   if (gobject == NULL)
     {
-      g_warning ("No object with id '%s' has been defined.", id);
+      g_warning ("No object with id '%s' has been defined.", id_);
       return;
     }
 
@@ -1579,7 +1579,7 @@ parse_animator_property (JsonArray *array,
       g_warning ("The object of type '%s' and name '%s' has no "
                  "property named '%s'",
                  G_OBJECT_TYPE_NAME (gobject),
-                 id,
+                 id_,
                  pname);
       return;
     }
@@ -2020,7 +2020,7 @@ clutter_animator_key_get_object (const ClutterAnimatorKey *key)
  *
  * Since: 1.2
  */
-G_CONST_RETURN gchar *
+const gchar *
 clutter_animator_key_get_property_name (const ClutterAnimatorKey *key)
 {
   g_return_val_if_fail (key != NULL, NULL);
