@@ -76,6 +76,8 @@
 #include <gobject/gvaluecollector.h>
 
 #include "clutter-box.h"
+
+#include "clutter-actor-private.h"
 #include "clutter-debug.h"
 #include "clutter-enum-types.h"
 #include "clutter-marshal.h"
@@ -296,6 +298,46 @@ clutter_box_real_paint (ClutterActor *actor)
   g_list_foreach (priv->children, (GFunc) clutter_actor_paint, NULL);
 }
 
+static gboolean
+clutter_box_real_get_paint_volume (ClutterActor       *actor,
+                                   ClutterPaintVolume *volume)
+{
+  ClutterBoxPrivate *priv = CLUTTER_BOX (actor)->priv;
+  gboolean retval = FALSE;
+  GList *l;
+
+  /* if we have a background color, and an allocation, then we need to
+   * set it as the base of our paint volume
+   */
+  if (priv->color_set)
+    retval = clutter_paint_volume_set_from_allocation (volume, actor);
+
+  /* bail out early if we don't have any child */
+  if (priv->children == NULL)
+    return retval;
+  else
+    retval = TRUE;
+
+  /* otherwise, union the paint volumes of our children, in case
+   * any one of them decides to paint outside the parent's allocation
+   */
+  for (l = priv->children; l != NULL; l = l->next)
+    {
+      ClutterActor *child = l->data;
+      const ClutterPaintVolume *child_volume;
+
+      /* This gets the paint volume of the child transformed into the
+       * group's coordinate space... */
+      child_volume = clutter_actor_get_transformed_paint_volume (child, actor);
+      if (!child_volume)
+        return FALSE;
+
+      clutter_paint_volume_union (volume, child_volume);
+    }
+
+  return retval;
+}
+
 static void
 clutter_box_real_pick (ClutterActor       *actor,
                        const ClutterColor *pick)
@@ -476,6 +518,7 @@ clutter_box_class_init (ClutterBoxClass *klass)
   actor_class->get_preferred_height = clutter_box_real_get_preferred_height;
   actor_class->allocate = clutter_box_real_allocate;
   actor_class->paint = clutter_box_real_paint;
+  actor_class->get_paint_volume = clutter_box_real_get_paint_volume;
   actor_class->pick = clutter_box_real_pick;
   actor_class->destroy = clutter_box_destroy;
 
@@ -738,14 +781,9 @@ clutter_box_set_property_valist (ClutterBox   *box,
           break;
         }
 
-#if GLIB_CHECK_VERSION (2, 23, 2)
       G_VALUE_COLLECT_INIT (&value, G_PARAM_SPEC_VALUE_TYPE (pspec),
                             var_args, 0,
                             &error);
-#else
-      g_value_init (&value, G_PARAM_SPEC_VALUE_TYPE (pspec));
-      G_VALUE_COLLECT (&value, var_args, 0, &error);
-#endif /* GLIB_CHECK_VERSION (2, 23, 2) */
 
       if (error)
         {
@@ -983,7 +1021,7 @@ clutter_box_set_color (ClutterBox         *box,
 /**
  * clutter_box_get_color:
  * @box: a #ClutterBox
- * @color: (out): return location for a #ClutterColor
+ * @color: (out caller-allocates): return location for a #ClutterColor
  *
  * Retrieves the background color of @box
  *
