@@ -799,7 +799,7 @@ clutter_script_get_type_from_name (ClutterScript *script,
  *
  * Since: 0.6
  */
-G_CONST_RETURN gchar *
+const gchar *
 clutter_get_script_id (GObject *gobject)
 {
   g_return_val_if_fail (G_IS_OBJECT (gobject), NULL);
@@ -1196,7 +1196,7 @@ _clutter_script_generate_fake_id (ClutterScript *script)
 /*
  * _clutter_script_warn_missing_attribute:
  * @script: a #ClutterScript
- * @id: the id of an object definition, or %NULL
+ * @id_: the id of an object definition, or %NULL
  * @attribute: the expected attribute
  *
  * Emits a warning, using GLib's log facilities, for a missing
@@ -1205,19 +1205,19 @@ _clutter_script_generate_fake_id (ClutterScript *script)
  */
 void
 _clutter_script_warn_missing_attribute (ClutterScript *script,
-                                        const gchar   *id,
+                                        const gchar   *id_,
                                         const gchar   *attribute)
 {
   ClutterScriptPrivate *priv = script->priv;
   JsonParser *parser = JSON_PARSER (priv->parser);
   gint current_line = json_parser_get_current_line (parser);
 
-  if (id != NULL && *id != '\0')
+  if (id_ != NULL && *id_ != '\0')
     {
       g_warning ("%s:%d: object '%s' has no '%s' attribute",
                  priv->is_filename ? priv->filename : "<input>",
                  current_line,
-                 id,
+                 id_,
                  attribute);
     }
   else
