@@ -30,7 +30,7 @@
 #include "clutter-backend.h"
 #include "clutter-debug.h"
 #include "clutter-device-manager-private.h"
-#include "clutter-event.h"
+#include "clutter-event-private.h"
 #include "clutter-keysyms.h"
 #include "clutter-main.h"
 #include "clutter-private.h"
@@ -129,8 +129,8 @@ static const struct
     { VK_LCONTROL, CLUTTER_KEY_Control_L },
     { VK_RCONTROL, CLUTTER_KEY_Control_R }
   };
-#define CLUTTER_WIN32_KEY_MAP_SIZE (sizeof (clutter_win32_key_map) \
-				    / sizeof (clutter_win32_key_map[0]))
+
+#define CLUTTER_WIN32_KEY_MAP_SIZE      (G_N_ELEMENTS (clutter_win32_key_map))
 
 static GSource *
 clutter_event_source_new (ClutterBackend *backend)
@@ -140,6 +140,8 @@ clutter_event_source_new (ClutterBackend *backend)
 
   event_source->backend = backend;
 
+  g_source_set_name (source, "Clutter Win32 Event Source");
+
   return source;
 }
 
@@ -204,17 +206,13 @@ get_modifier_state (WPARAM wparam)
   return ret;
 }
 
-static void
+static inline void
 take_and_queue_event (ClutterEvent *event)
 {
-  ClutterMainContext *clutter_context;
-
-  clutter_context = _clutter_context_get_default ();
-
   /* The event is added directly to the queue instead of using
      clutter_event_put so that it can avoid a copy. This takes
      ownership of the event */
-  g_queue_push_head (clutter_context->events_queue, event);
+  _clutter_event_push (event, FALSE);
 }
 
 static inline void
@@ -228,14 +226,16 @@ make_button_event (const MSG *msg,
   ClutterEvent *event = clutter_event_new (release ?
                                            CLUTTER_BUTTON_RELEASE :
                                            CLUTTER_BUTTON_PRESS);
+
+  event->any.stage = stage;
+
   event->button.time = msg->time;
   event->button.x = GET_X_LPARAM (msg->lParam);
   event->button.y = GET_Y_LPARAM (msg->lParam);
   event->button.modifier_state = get_modifier_state (msg->wParam);
   event->button.button = button;
   event->button.click_count = click_count;
-  event->button.device = device;
-  event->any.stage = stage;
+  clutter_event_set_device (event, device);
 
   take_and_queue_event (event);
 }
@@ -512,9 +512,10 @@ clutter_win32_handle_event (const MSG *msg)
           event->scroll.time = msg->time;
           event->scroll.modifier_state =
             get_modifier_state (LOWORD (msg->wParam));
-          event->scroll.device = core_pointer;
           event->any.stage = stage;
 
+          clutter_event_set_device (event, core_pointer);
+
           /* conversion to window coordinates is required */
           pt.x = GET_X_LPARAM (msg->lParam);
           pt.y = GET_Y_LPARAM (msg->lParam);
@@ -545,13 +546,15 @@ clutter_win32_handle_event (const MSG *msg)
         event->motion.x = GET_X_LPARAM (msg->lParam);
         event->motion.y = GET_Y_LPARAM (msg->lParam);
         event->motion.modifier_state = get_modifier_state (msg->wParam);
-        event->motion.device = core_pointer;
         event->any.stage = stage;
 
+        clutter_event_set_device (event, core_pointer);
+
         /* We need to start tracking when the mouse enters the stage if
            we're not already */
         if (!stage_win32->tracking_mouse)
           {
+            ClutterEvent *crossing = clutter_event_new (CLUTTER_ENTER);
             TRACKMOUSEEVENT tmevent;
 
             tmevent.cbSize = sizeof (tmevent);
@@ -559,8 +562,19 @@ clutter_win32_handle_event (const MSG *msg)
             tmevent.hwndTrack = stage_win32->hwnd;
             TrackMouseEvent (&tmevent);
 
+            event->crossing.time = msg->time;
+            event->crossing.x = event->motion.x;
+            event->crossing.y = event->motion.y;
+            event->crossing.stage = stage;
+            event->crossing.source = CLUTTER_ACTOR (stage);
+            event->crossing.related = NULL;
+
+            clutter_event_set_device (event, core_pointer);
+
             /* we entered the stage */
-            _clutter_input_device_set_stage (event->motion.device, stage);
+            _clutter_stage_add_device (stage, core_pointer);
+
+            take_and_queue_event (crossing);
 
             stage_win32->tracking_mouse = TRUE;
           }
@@ -576,11 +590,14 @@ clutter_win32_handle_event (const MSG *msg)
         event->crossing.time = msg->time;
         event->crossing.x = msg->pt.x;
         event->crossing.y = msg->pt.y;
-        event->crossing.device = core_pointer;
-        event->any.stage = stage;
+        event->crossing.stage = stage;
+        event->crossing.source = CLUTTER_ACTOR (stage);
+        event->crossing.related = NULL;
+
+        clutter_event_set_device (event, core_pointer);
 
         /* we left the stage */
-        _clutter_input_device_set_stage (event->crossing.device, NULL);
+        _clutter_stage_remove_device (stage, core_pointer);
 
         /* When we get a leave message the mouse tracking is
            automatically cancelled so we'll need to start it again when
@@ -669,9 +686,10 @@ clutter_win32_handle_event (const MSG *msg)
 	event->key.time = msg->time;
 	event->key.modifier_state = get_key_modifier_state (key_states);
 	event->key.hardware_keycode = scan_code;
-        event->key.device = core_keyboard;
         event->any.stage = stage;
 
+        clutter_event_set_device (event, core_keyboard);
+
         take_and_queue_event (event);
       }
       break;
