@@ -36,7 +36,7 @@
 #include "clutter-device-manager-private.h"
 #include "clutter-enum-types.h"
 #include "clutter-event-translator.h"
-#include "clutter-event.h"
+#include "clutter-event-private.h"
 #include "clutter-feature.h"
 #include "clutter-main.h"
 #include "clutter-paint-volume-private.h"
@@ -220,7 +220,6 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
 {
   ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
   ClutterBackendX11 *backend_x11 = stage_x11->backend;
-  gboolean resize;
 
   if (stage_x11->is_foreign_xwin)
     {
@@ -238,8 +237,6 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
   if (stage_x11->fullscreening)
     return;
 
-  resize = clutter_stage_get_user_resizable (stage_x11->wrapper);
-
   if (width == 0 || height == 0)
     {
       /* Should not happen, if this turns up we need to debug it and
@@ -465,6 +462,7 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
 
   if (is_fullscreen)
     {
+#if 0
       int width, height;
 
       /* FIXME: this will do the wrong thing for dual-headed
@@ -474,6 +472,7 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
          until the ConfigureNotify for the correct size is received */
       width  = DisplayWidth (backend_x11->xdpy, backend_x11->xscreen_num);
       height = DisplayHeight (backend_x11->xdpy, backend_x11->xscreen_num);
+#endif
 
       /* Set the fullscreen hint so we can retain the old size of the window. */
       stage_x11->fullscreening = TRUE;
